{ config, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
      ./network.nix
      ./microvm-staging.nix
      ./microvms.nix
    ];

  # Use the GRUB 2 boot loader.
  boot.loader.grub.enable = true;
  boot.loader.grub.version = 2;
  # boot.loader.grub.efiSupport = true;
  # boot.loader.grub.efiInstallAsRemovable = true;
  # boot.loader.efi.efiSysMountPoint = "/boot/efi";
  # Define on which hard drive you want to install Grub.
  boot.loader.grub.device = "/dev/sda"; # or "nodev" for efi only

  # FIXME: Package ‘zfs-kernel-2.1.4-5.18’ is marked as broken
  # boot.kernelPackages = pkgs.linuxPackages_latest;
  # FIXME: kernel null ptr derefs
  # boot.kernelPackages = pkgs.linuxPackages_5_17;

  boot.kernelParams = [
    "preempt=none"
    # No server/router runs any untrusted user code
    "mitigations=off"
  ];
  boot.tmpOnTmpfs = true;
  boot.tmpOnTmpfsSize = "80%";
  
  networking.hostName = "server10"; # Define your hostname.
  networking.hostId = "10101010";

  networking.firewall = {
    enable = true;
    allowedTCPPorts = [ 22 ];
  };
  services.openssh.enable = true;

  c3d2.hq.statistics.enable = true;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "21.11"; # Did you read the comment?
}
